@@ -14,13 +14,11 @@ type Version struct {
 	Build    string
 }
 
-var (
-	// DelveVersion is the current version of Delve.
-	DelveVersion = Version{
-		Major: "1", Minor: "23", Patch: "1", Metadata: "",
-		Build: "$Id: 2eba762d75437d380e48fc42213853f13aa2904d $",
-	}
-)
+// DelveVersion is the current version of Delve.
+var DelveVersion = Version{
+	Major: "1", Minor: "24", Patch: "0", Metadata: "",
+	Build: "$Id: 2d55e4d30150e3fc68e64357e21293d7920fc1f1 $",
+}
 
 func (v Version) String() string {
 	fixBuild(&v)
